reckon_gater_app (reckon_gater v1.3.0)
View SourceApplication module for reckon-gater
The gateway provides distributed worker registration and load balancing for reckon-db event stores.
Application module for reckon-gater
The gateway provides distributed worker registration and load balancing for reckon-db event stores.